Optimize this so that we can better guess where to start scanning
from.  We know the length of the register field format, therefore
given the file pointer position align to the nearest register
field and scan from there onwards.  We round down in this calculation
and we let the rest of the code figure out where to start scanning
from.

Signed-off-by: Dimitris Papastamos <d...@opensource.wolfsonmicro.com>
---
 drivers/base/regmap/regmap-debugfs.c | 12 +++++++-----
 1 file changed, 7 insertions(+), 5 deletions(-)

diff --git a/drivers/base/regmap/regmap-debugfs.c 
b/drivers/base/regmap/regmap-debugfs.c
index 5fa2e6d..8584fac 100644
--- a/drivers/base/regmap/regmap-debugfs.c
+++ b/drivers/base/regmap/regmap-debugfs.c
@@ -139,15 +139,17 @@ static unsigned int regmap_debugfs_get_dump_start(struct 
regmap *map,
        WARN_ON(list_empty(&map->debugfs_off_cache));
        ret = base;
 
        /* Find the relevant block */
        list_for_each_entry(c, &map->debugfs_off_cache, list) {
                if (from >= c->min && from <= c->max) {
-                       *pos = c->min;
-                       return c->base_reg;
+                       fpos_offset = from - c->min;
+                       reg_offset = fpos_offset / map->debugfs_tot_len;
+                       *pos = c->min + (reg_offset * map->debugfs_tot_len);
+                       return c->base_reg + reg_offset;
                }
 
-               *pos = c->min;
-               ret = c->base_reg;
+               *pos = c->max;
+               ret = c->max_reg;
        }
 
        return ret;
@@ -139,15 +139,17 @@ static unsigned int regmap_debugfs_get_dump_start(struct 
        ret = base;
 
-       /* Find the relevant block */
+       /* Find the relevant block:offset */
        list_for_each_entry(c, &map->debugfs_off_cache, list) {
                if (from >= c->min && from <= c->max) {
-- 
1.8.1.2

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to